#!/usr/bin/perl -w
#
# /etc/sperren/name2ip.pl
#
# Tool zur Auswertung der Datei dhcpd.leases
# das aus der Datei dhcpd.leases eine Datei squid.sperren_raum erzeugt,
# in der neben den nach Raeumen sortierten NETBIOS-Namen die 
# aktuellen IP-Nummern stehen.
#
# Gisbert Friege, 28.6.2002
# gfriege@t-online.de
#
# Wenn eine Datei mit dem Namen raeume existiert, in der jede Zeile 
# einen Raumnamen enthaelt, dann werden die Rechner raumweise
# sortiert ausgegeben.
# Rechner, die nicht mit dem Raumnamen beginnen,
# werden dem Raum ANDERE zugeordnet.
# 
# Beispieldatei raeume enthaelt die Zeilen:
# Info01
# Info02
# 
# Beispiel fuer die NETBIOS-Namen:
# Info01_PC01
# Info01_Lehrer
# Info02_Aachen
# Info02_Berlin
# Service
# Reserve
# 
# Dieses Beispiel ergibt die Datei squid.sperren_raum
# z.B. mit folgendem Inhalt (IPs aus dhcpd.leases)
#
# Raum Info01
# Info01_Lehrer 192.168.0.34
# Info01_PC01 192.168.0.123
# Info01_PC02 192.168.0.99
# Raum Info02
# Info02_Aachen 192.168.0.123
# Info02_Berlin 192.168.0.34
# Raum ANDERE
# Reserve 192.168.150
# Service 192.168.200
#
# Innerhalb der Raumgruppen erscheinen die Rechner alphabetisch sortiert
#

$leases="/var/state/dhcp/dhcpd.leases";
#$leases="dhcpd.leases"; # Kopie fuer Tests innerhalb von /etc/sperren

$raeume="/etc/sperren/raeume"; 
$plaetze="/etc/sperren/squid.sperren_raum";
#$plaetze="/etc/sperren/_squid.sperren_raum"; # fuer Tests, 
                       # die squid.sperren_raum nicht veraendern sollen

# Einlesen der relevanten Zeilen aus dhcpd.leases in den Hash %paare
open(LDAT,"< $leases") || die "\nKann Leasesdatei $leases nicht oeffnen\n";
%paare = ();
while (<LDAT>) {
    if (not ($_=~ /#/) and (($_=~ /lea/) or ($_=~ /cli/)))  {
	if (/^lease\s(.*)\s{.*/) {
	$ip = $1 ;
	}
	elsif (/.*name\s"(.*)".*;/) {
	$paare{$1} = $ip;
	}
    }
}
close(LDAT);

# Raeume werden eingelesen in den Array @raumarray
open(RDAT,"< $raeume") || die "\nKann Raeumedatei $raeume nicht oeffnen\n";
@raumarray = ();
while (<RDAT>){
    chomp($_);
    push (@raumarray,$_);
}
close(RDAT);

# jetzt Ausgabe...
open(AUSDAT,"> $plaetze") || die "\nKann Ausgabedatei $plaetze nicht oeffnen\n";
# ... erstmal die fuer die Raeume
foreach (@raumarray) { 
    printf AUSDAT "Raum $_\n"; 
    foreach $key (sort(keys %paare)) {
	if ((index $key, $_) == 0) {
	$wert = $paare{$key};
	printf AUSDAT "$key $wert\n";
	}
    }	
}

# ... und jetzt den Rest
print AUSDAT "Raum ANDERE\n";
foreach $key (sort(keys %paare)) {
	$passt = 0;
	foreach (@raumarray) {
	    if ((index $key, $_) == 0) {
	    $passt = 1;
	    }
	}    
	if ($passt != 1){
	    $wert = $paare{$key};
	    printf AUSDAT "$key $wert\n";
	}
}

close(AUSDAT);
exit;

