#!/bin/bash
# Installation des Paketes sperren.tar
# Autor: Dr. Dieter Heimann, Robert-Bosch-Berufskolleg, Dortmund
# letzte Aenderung: 14. Mrz 2001
# Aenderungen durch G.Friege, FALS Solingen, fuer automatische
# Clientnamen -> IP-Zuordnung (verwendet dhcpd.leases):
# 
# Datei /etc/sperren/raeume muss nach Installation angepasst werden
#

# $Id: doinst.sh,v 1.4 2007-03-29 15:04:12+02 HHullen Exp $
# $Log: doinst.sh,v $

# Revision 1.5  2007-04-09 21:05:00+02  GFriege
# Anpassung fuer Arkturi 3.3,3.4,3.5,4.0 (G.Friege) 
# Verschiedene Korrekturen u.a. fuer Arktur 4:
# Such-Zeile "acl denied_hosts" eingefuegt, 
# da "acl verboten" in squid.conf bei Arktur 4 nicht vorhanden

# Revision 1.4  2007-03-29 15:04:12+02  HHullen
# reconfigure wird in zugang.conf angepasst
#
# Revision 1.3  2007-03-28 15:29:09+02  HHullen
# case-Struktur korrigiert
#
# Revision 1.2  2007-03-28 15:24:05+02  HHullen
# reduziert auf 1 Paket fuer alle Versionen
#
# Revision 1.1  2007-03-28 14:39:02+02  GFriege
# Start
#

# set -x # ausfuehrlicheres log in /var/adm/packages/...

#echo $PATH

test -f $(dirname $0)/odsconf && source $(dirname $0)/odsconf

for Datei in etc/zugang.conf.neu \
    etc/sperren/{raeume,squid.sperren_{ip,raum}}.neu
  do
    config $Datei
  done
      
Version=$(< /usr/lib/ods-server/version)

test "$Version" || exit 1

Lager=tmp/sperren_dhcp

INSTDIRETC=/etc
INSTDIRSQUID=${INSTDIRETC}/sperren
SUDOERS=/etc/sudoers
SQUIDFILE=/etc/squid/squid.conf
SQUIDFILEIN=${SQUIDFILE}.in
JOBDIR=/usr/lib/ods-server/cron

case $Version in
    V3\.[0-3]*|3\.1)
    INSTDIRCGI=/home/www/admin
    Owner=www
    Bindir="/usr/squid/bin"
    SudoMod="440"
    ;;
    V3\.4*)
    INSTDIRCGI=/usr/www/admin
    Owner="wwwrun:www"
    Bindir="/usr/sbin"
    SudoMod="440"
    ;;
    v3\.5*)
    INSTDIRCGI=/usr/www/admin
    Owner="wwwrun:www"
    Bindir="/usr/squid/sbin"
    SudoMod="640"
    ;;
    V4\.0*)
    INSTDIRCGI=/usr/www/secure/admin
    Owner="wwwrun:www"
    Bindir="/usr/squid/sbin"
    SudoMod="640"
    ;;
    *)
    exit 1
    ;;
esac
    

chmod 755 $INSTDIRSQUID

chmod 640 $INSTDIRSQUID/*

chown -R $Owner $INSTDIRSQUID

chown $Owner $Lager/*.cgi

cp -a $Lager/*.cgi $INSTDIRCGI

# Log Verzeichnis anlegen
mkdir -p $INSTDIRCGI/log

chmod 750 $INSTDIRCGI/log

chown $Owner $INSTDIRCGI/log

# Aenderungen in /etc/sudoers
if [ -f $SUDOERS ]; then

  chmod $SudoMod $SUDOERS
    
  RESULT=$(grep "# Reconfigure durch den Webserver erlauben" $SUDOERS)
  if [ -z "$RESULT" ]; then
    cp $SUDOERS $SUDOERS.org$$
    rm -f $SUDOERS
    while read LINE ; do
     case "$LINE" in
      \#\ User* )
         echo "# Reconfigure durch den Webserver erlauben" >> $SUDOERS 
         echo "${Owner%:*}		ALL=NOPASSWD: $Bindir/squid" >> $SUDOERS
         echo "" >> $SUDOERS
            ;;
     esac
     echo -E "$LINE" >> $SUDOERS
    done < $SUDOERS.org$$
  fi
else
  echo "${Owner%:*}           ALL=NOPASSWD: $Bindir/squid" >> $SUDOERS
fi


# Aederungen in /etc/squid.conf und /etc/squid.conf.in
if [ -f ${SQUIDFILEIN} ]; then
  RESULT=$(grep "acl sperren_ip src" $SQUIDFILE)
  if [ -z "$RESULT" ]; then
# Sicherung der alten Datei
    cp ${SQUIDFILEIN} ${SQUIDFILEIN}.org.$$
    rm -f $SQUIDFILE
    while read LINE ; do
      echo -E "$LINE" >> $SQUIDFILE
      case "$LINE" in
       \acl\ verboten* )
               echo "acl sperren_ip src \"$INSTDIRSQUID/squid.sperren_ip\"" >> $SQUIDFILE
         ;;
       \acl\ denied_hosts* )
               echo "acl sperren_ip src \"$INSTDIRSQUID/squid.sperren_ip\"" >> $SQUIDFILE
         ;;
       \http_access\ deny\ verboten* )
             echo "http_access deny all !sperren_ip" >> $SQUIDFILE
	;;
       \http_access\ deny\ denied_hosts* )
             echo "http_access deny all !sperren_ip" >> $SQUIDFILE
         ;;
      esac
    done < ${SQUIDFILEIN}
    cp $SQUIDFILE ${SQUIDFILEIN}
  fi
fi
# pidof squid >/dev/null 2>&1 && killall -HUP squid
$Bindir/squid -k reconfigure

rm -rf $Lager # da sind die cgi-s drin!  

# Ende Zusatz gf
# Ende Verschlankung HHullen

Datei=$INSTDIRETC/zugang.conf
ed -s $Datei <<EOF
/^cmdsquid/
c
cmdsquid="sudo $Bindir/squid -k reconfigure" 
.
wq
EOF

chmod $SudoMod $SUDOERS

#
 